'use strict';

exports.__esModule = true;
exports.createFormFields = createFormFields;

var _utils = require('../utils');

var formUtils = _interopRequireWildcard(_utils);

var _formConstants = require('../enums/formConstants');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function createFormFields(props, state) {
  var fields = {};

  for (var _iterator = Object.keys(state), _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
    var _ref;

    if (_isArray) {
      if (_i >= _iterator.length) break;
      _ref = _iterator[_i++];
    } else {
      _i = _iterator.next();
      if (_i.done) break;
      _ref = _i.value;
    }

    var fieldStateId = _ref;

    var _formUtils$parseField = formUtils.parseFieldStateId(fieldStateId);

    var dataType = _formUtils$parseField.dataType;
    var fieldId = _formUtils$parseField.fieldId;


    if (!fields[fieldId]) {
      fields[fieldId] = {};
    }

    if (dataType === _formConstants.formConstants.FIELD_DATA_STATE_ID_PREFIX) {
      fields[fieldId].props = state[fieldStateId];
    } else {
      fields[fieldId].message = state[fieldStateId].message;
      fields[fieldId].status = state[fieldStateId].status;
    }
  }

  var singleDataSource = formUtils.singleDataSource(props);

  function getPropsFor() {
    for (var _len = arguments.length, keyPath = Array(_len), _key = 0; _key < _len; _key++) {
      keyPath[_key] = arguments[_key];
    }

    var fieldId = formUtils.getFieldIdFromKeyPath(singleDataSource, keyPath);
    return this.fields[fieldId].props;
  }

  function getValidFor() {
    for (var _len2 = arguments.length, keyPath = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      keyPath[_key2] = arguments[_key2];
    }

    var fieldId = formUtils.getFieldIdFromKeyPath(singleDataSource, keyPath);
    return this.fields[fieldId].valid;
  }

  function getMessageFor() {
    for (var _len3 = arguments.length, keyPath = Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
      keyPath[_key3] = arguments[_key3];
    }

    var fieldId = formUtils.getFieldIdFromKeyPath(singleDataSource, keyPath);
    return this.fields[fieldId].message;
  }

  function getStatusFor() {
    for (var _len4 = arguments.length, keyPath = Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
      keyPath[_key4] = arguments[_key4];
    }

    var fieldId = formUtils.getFieldIdFromKeyPath(singleDataSource, keyPath);
    return this.fields[fieldId].status;
  }

  function getFieldIdFor() {
    for (var _len5 = arguments.length, keyPath = Array(_len5), _key5 = 0; _key5 < _len5; _key5++) {
      keyPath[_key5] = arguments[_key5];
    }

    return formUtils.getFieldIdFromKeyPath(singleDataSource, keyPath);
  }

  function getDomIdFor(keyPath, suffix) {
    if (!Array.isArray(keyPath)) {
      throw new Error('`keyPath` passed to `fromFields.getFieldDomId` must be an Array');
    }

    return formUtils.getFieldDomIdFromKeyPath(singleDataSource, keyPath, suffix);
  }

  return {
    fields: fields,
    getPropsFor: getPropsFor,
    getValidFor: getValidFor,
    getMessageFor: getMessageFor,
    getStatusFor: getStatusFor,
    getFieldIdFor: getFieldIdFor,
    getDomIdFor: getDomIdFor
  };
}